@@ -35,9 +35,15 @@ public:
       Q_Q( SelectionProxyModel );
       foreach ( const QModelIndex &rootIndex, q->sourceRootIndexes() ) {
         rootIndexAdded( rootIndex );
-        q->sourceModel()->fetchMore( rootIndex );
       }
   }
+  ~SelectionProxyModelPrivate()
+  {
+    Q_Q( SelectionProxyModel );
+    foreach(const QModelIndex& idx, q->sourceRootIndexes()) {
+      rootIndexAboutToBeRemoved(idx);
+    }
+  }
 
   /**
     Increases the refcount of the Collection in @p newRootIndex
